<?php
/**
 * about Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add about section
$wp_customize->add_section( 'house_state_pro_about_section', array(
	'title'             => esc_html__( 'About','house-state-pro' ),
	'description'       => esc_html__( 'About Section options.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
  			house_state_pro_is_default_layout( $control )
  			||
  			house_state_pro_is_all_layout( $control )
  			||
  			house_state_pro_is_second_layout( $control )
        );
    },
) );


// about content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'about Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_about_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );


// about content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options_about_content_type', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options_about_content_type', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_about_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'house-state-pro' ),
            'post' 		=> esc_html__( 'Post', 'house-state-pro' ),
	),
) );


// about pages drop down chooser control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_page',
) );

$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[about_content_page]', array(
	'label'             => sprintf(esc_html__( 'Select Page', 'house-state-pro') ),
	'section'           => 'house_state_pro_about_section',
	'choices'			=> house_state_pro_page_choices(),
	'active_callback'	=> 'house_state_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_page',
) );

$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[about_content_post]', array(
	'label'             => sprintf(esc_html__( 'Select Post', 'house-state-pro') ),
	'section'           => 'house_state_pro_about_section',
	'choices'			=> house_state_pro_post_choices(),
	'active_callback'	=> 'house_state_pro_is_about_section_content_post_enable',
) ) );


//about_btn_txt
$wp_customize->add_setting('house_state_pro_theme_options[about_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_btn_txt'],
    )
);

$wp_customize->add_control('house_state_pro_theme_options[about_btn_txt]',
    array(
        'section'			=> 'house_state_pro_about_section',
        'label'				=> esc_html__( 'Button Text:', 'house-state-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'house_state_pro_is_about_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[about_btn_txt]', array(
		'selector'            => '#about-us-fullwidth article div.read-more a',
		'settings'            => 'house_state_pro_theme_options[about_btn_txt]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'house_state_pro_about_btn_txt_partial',
    ) );
}


// blog btn url setting and control
$wp_customize->add_setting( 'house_state_pro_theme_options[about_excerpt]', array(
	'sanitize_callback' => 'absint',
	'default'			=> $options['about_excerpt'],
) );

$wp_customize->add_control( 'house_state_pro_theme_options[about_excerpt]', array(
	'label'           	=> esc_html__( 'about Excerpt', 'house-state-pro' ),
	'section'        	=> 'house_state_pro_about_section',
	'active_callback' 	=> 'house_state_pro_is_about_section_enable',
	'type'				=> 'number',
) );



//style

$wp_customize->add_setting( 'house_state_pro_theme_options[style_about_overlay_enable]', array(
	'default'			=> 	false,
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[style_about_overlay_enable]', array(
	'label'             => esc_html__( 'About Overlay Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_about_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_about_overlay_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'

	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'house_state_pro_theme_options[style_about_overlay_color]', array(
	'label'             => esc_html__( 'Overlay Color', 'house-state-pro' ),
	'section'           => 'house_state_pro_about_section',
	'active_callback' 	=> 'house_state_pro_is_about_section_overlay_enable',
	) ) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_about_overlay_value]', array(
	'default'          	=> $options['style_about_overlay_value'],
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[style_about_overlay_value]', array(
	'label'             => esc_html__( 'Overlay Value', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 0 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_about_section',
	'type'				=> 'number',
	'active_callback' 	=> 'house_state_pro_is_about_section_overlay_enable',
	'input_attrs'		=> array(
		'min'	=> 0,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_about_background]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'house_state_pro_theme_options[style_about_background]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'house-state-pro' ),
		'section'     		=> 'house_state_pro_about_section',
) ) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_about_background_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'house_state_pro_theme_options[style_about_background_color]', array(
	'label'             => esc_html__( 'Background Color', 'house-state-pro' ),
	'section'           => 'house_state_pro_about_section',
	) ) );

