<?php
/**
 * counter Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add counter section
$wp_customize->add_section( 'house_state_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','house-state-pro' ),
	'description'       => esc_html__( 'Counter Section options.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
  			house_state_pro_is_default_layout( $control )
  			||
  			house_state_pro_is_second_layout( $control )
        );
    },
) );

// counter content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_counter_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

// editor choice image setting and control.
$wp_customize->add_setting( 'house_state_pro_theme_options[counter_background]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'house_state_pro_theme_options[counter_background]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'house-state-pro' ),
		'section'     		=> 'house_state_pro_counter_section',
		'active_callback'	=> 'house_state_pro_is_counter_section_enable',
) ) );


$wp_customize->add_setting( 'house_state_pro_theme_options[counter_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['counter_section_title'],
	'transport'			=>'refresh'
) );

$wp_customize->add_control('house_state_pro_theme_options[counter_section_title]', array(
	'label'             =>  esc_html__( 'Section Title', 'house-state-pro' ),
	'section'           => 'house_state_pro_counter_section',
	'type'              => 'text',
	'active_callback'	=> 'house_state_pro_is_counter_section_enable',
));

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[counter_section_title]', array(
		'selector'            => '#counter-section .section-header .section-title',
		'settings'            => 'house_state_pro_theme_options[counter_section_title]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'house_state_pro_counter_title_txt_partial',
    ) );
}


$wp_customize->add_setting( 'house_state_pro_theme_options[counter_column]', array(
	'default'          	=> $options['counter_column'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[counter_column]', array(
	'label'             => esc_html__( 'Column', 'house-state-pro' ),
	'section'           => 'house_state_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_counter_section_enable',
	'choices'			=> array( 
            'col-1' 		=> esc_html__( 'Column 1', 'house-state-pro' ),
            'col-2' 		=> esc_html__( 'Column 2', 'house-state-pro' ),
            'col-3' 		=> esc_html__( 'Column 3', 'house-state-pro' ),
            'col-4' 		=> esc_html__( 'Column 4', 'house-state-pro' ),
	),
) );

// counter number control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_counter_section',
	'active_callback'   => 'house_state_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 15,
		'style' => 'width: 100px;'
		),
) );


for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	$wp_customize->add_setting( 'house_state_pro_theme_options[counter_content_icon_' . $i . ']', array(
			'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new House_State_Pro_Icon_Picker( $wp_customize, 'house_state_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'house-state-pro' ), $i ),
		'section'           => 'house_state_pro_counter_section',
		'active_callback'	=> 'house_state_pro_is_counter_section_enable',
	) ) );
	
	$wp_customize->add_setting( 'house_state_pro_theme_options[counter_section_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'refresh'
	) );

	$wp_customize->add_control('house_state_pro_theme_options[counter_section_number_' . $i . ']', array(
		'label'             =>  esc_html__( 'Counter Number', 'house-state-pro' ),
		'section'           => 'house_state_pro_counter_section',
		'type'              => 'text',
		'active_callback'	=> 'house_state_pro_is_counter_section_enable',
	));

	$wp_customize->add_setting( 'house_state_pro_theme_options[counter_section_text_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'refresh'
	) );

	$wp_customize->add_control('house_state_pro_theme_options[counter_section_text_' . $i . ']', array(
		'label'             =>  esc_html__( 'Counter Text', 'house-state-pro' ),
		'section'           => 'house_state_pro_counter_section',
		'type'              => 'text',
		'active_callback'	=> 'house_state_pro_is_counter_section_enable',
	));


endfor;

