<?php
/**
 * featured_products Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add featured_products section
$wp_customize->add_section( 'house_state_pro_featured_products_section', array(
	'title'             => esc_html__( 'Featured Products','house-state-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
  			house_state_pro_is_all_layout( $control )
  			||
  			house_state_pro_is_third_layout( $control )
        );
    },
) );

// featured_products content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[featured_products_section_enable]', array(
	'default'			=> 	$options['featured_products_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[featured_products_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_featured_products_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[featured_products_section_enable]', array(
        'selector'            => '#featured-products .wrapper',
        'settings'            => 'house_state_pro_theme_options[featured_products_section_enable]',
    ) );
}

for ( $i = 1; $i <= 2; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'house_state_pro_theme_options[featured_products_content_featured_products_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize,'house_state_pro_theme_options[featured_products_content_featured_products_category_'.$i.']', array(
		'label'             => esc_html__( 'Select Featured Category ', 'house-state-pro' ).$i,
		'section'           => 'house_state_pro_featured_products_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'house_state_pro_is_featured_products_section_enable'
	) ) );

	$wp_customize->add_setting( 'house_state_pro_theme_options[featured_products_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'house_state_pro_theme_options[featured_products_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Title ', 'house-state-pro' ).$i,
		'section'        	=> 'house_state_pro_featured_products_section',
		'active_callback' 	=> 'house_state_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'house_state_pro_theme_options[featured_products_short_description_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'house_state_pro_theme_options[featured_products_short_description_'.$i.']', array(
		'label'           	=> esc_html__( 'Short Description ', 'house-state-pro' ).$i,
		'section'        	=> 'house_state_pro_featured_products_section',
		'active_callback' 	=> 'house_state_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	) );

endfor;

// featured_products btn title setting and control
$wp_customize->add_setting( 'house_state_pro_theme_options[featured_products_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[featured_products_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label ', 'house-state-pro' ),
	'section'        	=> 'house_state_pro_featured_products_section',
	'active_callback' 	=> 'house_state_pro_is_featured_products_section_enable',
	'type'				=> 'text',
) );

