<?php
/**
 * popular_post Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add popular_post section
$wp_customize->add_section( 'house_state_pro_popular_post_section', array(
	'title'             => esc_html__( 'Popular Post','house-state-pro' ),
	'description'       => esc_html__( 'Popular Post Section options.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
  			house_state_pro_is_all_layout( $control )
  			||
  			house_state_pro_is_magazine_layout( $control )
        );
    },
) );

// popular_post content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_section_enable]', array(
	'default'			=> 	$options['popular_post_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[popular_post_section_enable]', array(
	'label'             => esc_html__( 'popular_post Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_popular_post_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );


$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_excerpt]', array(
	'sanitize_callback' => 'absint',
	'default'			=> 30,
) );

$wp_customize->add_control( 'house_state_pro_theme_options[popular_post_excerpt]', array(
	'label'           	=> esc_html__( 'Excerpt Lenght', 'house-state-pro' ),
	'section'        	=> 'house_state_pro_popular_post_section',
	'active_callback' 	=> 'house_state_pro_is_popular_post_section_enable',
	'type'				=> 'number',
) );


$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_post_section_title'],
	'transport'			=>'refresh'
) );

$wp_customize->add_control('house_state_pro_theme_options[popular_post_section_title]', array(
	'label'             =>  esc_html__( 'Section Title', 'house-state-pro' ),
	'section'           => 'house_state_pro_popular_post_section',
	'type'              => 'text',
	'active_callback'	=> 'house_state_pro_is_popular_post_section_enable',
));

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[popular_post_section_title]', array(
		'selector'            => '#latest-posts .section-header .section-title',
		'settings'            => 'house_state_pro_theme_options[popular_post_section_title]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'house_state_pro_service_title_txt_partial',
    ) );
}


// popular_post number control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_count]', array(
	'default'          	=> $options['popular_post_count'],
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[popular_post_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_popular_post_section',
	'active_callback'   => 'house_state_pro_is_popular_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 15,
		'style' => 'width: 100px;'
		),
) );

// popular_post content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_content_type]', array(
	'default'          	=> $options['popular_post_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[popular_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_popular_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_popular_post_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'house-state-pro' ),
            'post' 		=> esc_html__( 'Post', 'house-state-pro' ),
            'category' 	=> esc_html__( 'Category', 'house-state-pro' ),
	),
) );


for ( $i = 1; $i <= $options['popular_post_count']; $i++ ) :

	// popular_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_content_page_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[popular_post_content_page_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_popular_post_section',
		'choices'			=> house_state_pro_page_choices(),
		'active_callback'	=> 'house_state_pro_is_popular_post_section_content_page_enable',
	) ) );

	// popular_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_content_post_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[popular_post_content_post_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_popular_post_section',
		'choices'			=> house_state_pro_post_choices(),
		'active_callback'	=> 'house_state_pro_is_popular_post_section_content_post_enable',
	) ) );

endfor;

// popular_post posts drop down chooser control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[popular_post_category]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_single_category',
) );

$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'house_state_pro_theme_options[popular_post_category]', array(
	'label'             => esc_html__( 'Select Categories', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'house-state-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'house_state_pro_popular_post_section',
	'active_callback'	=> 'house_state_pro_is_popular_post_section_content_category_enable',
) ) ); 

