<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'house_state_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','house-state-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            house_state_pro_is_all_layout( $control )
            ||
            house_state_pro_is_default_layout( $control )
            ||
            house_state_pro_is_second_layout( $control )
            ||
            house_state_pro_is_third_layout( $control )
        );
    },
) );


// Slider content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_slider_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[slider_autoplay_enable]', array(
	'default'			=> 	$options['slider_autoplay_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_slider_section',
	'active_callback'   => 'house_state_pro_is_slider_section_enable',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );


// Slider number control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options_slider_count', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
	'validate_callback' => 'house_state_pro_validate_slider_count',
) );

$wp_customize->add_control( 'house_state_pro_theme_options_slider_count', array(
	'label'             => esc_html__( 'Number of Featured', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_slider_section',
	'active_callback'   => 'house_state_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 15,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options_slider_content_type', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options_slider_content_type', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_slider_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'house-state-pro' ),
            'post' 		=> esc_html__( 'Post', 'house-state-pro' ),
            'category' 	=> esc_html__( 'Category', 'house-state-pro' ),
	),
) );


for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

		
	// slider section title control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[slider_section_sub_title_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_section_sub_title'],
		'transport'			=>'refresh'
	) );

	$wp_customize->add_control('house_state_pro_theme_options[slider_section_sub_title_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Section Sub Title %d', 'house-state-pro' ), $i),
		'section'           => 'house_state_pro_slider_section',
		'type'              =>'text',
		'active_callback'	=> 'house_state_pro_is_slider_section_enable',
	));

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[slider_content_page_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[slider_content_page_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_slider_section',
		'choices'			=> house_state_pro_page_choices(),
		'active_callback'	=> 'house_state_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[slider_content_post_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[slider_content_post_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_slider_section',
		'choices'			=> house_state_pro_post_choices(),
		'active_callback'	=> 'house_state_pro_is_slider_section_content_post_enable',
	) ) );

	//house_state_pro_Customize_Horizontal_Line
    $wp_customize->add_setting('house_state_pro_theme_options[slider_separator'. $i .']',array(
       'sanitize_callback'      => 'house_state_pro_sanitize_html',
    ));

    $wp_customize->add_control(new House_State_Pro_Customize_Horizontal_Line($wp_customize,'house_state_pro_theme_options[slider_separator'. $i .']',array(
        'active_callback'       => 'house_state_pro_is_slider_section_separator_enable',
        'type'                  =>'hr',
        'section'               =>'house_state_pro_slider_section',
    )));

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[slider_category]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_single_category',
) );

$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'house_state_pro_theme_options[slider_category]', array(
	'label'             => esc_html__( 'Select Categories', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'house-state-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'house_state_pro_slider_section',
	'active_callback'	=> 'house_state_pro_is_slider_section_content_category_enable',
) ) ); 

//slider_btn_txt
$wp_customize->add_setting('house_state_pro_theme_options[slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_txt'],
    )
);

$wp_customize->add_control('house_state_pro_theme_options[slider_btn_txt]',
    array(
        'section'			=> 'house_state_pro_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'house-state-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'house_state_pro_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[slider_btn_txt]', array(
		'selector'            => '#featured-slider-section article div.read-more a',
		'settings'            => 'house_state_pro_theme_options[slider_btn_txt]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'house_state_pro_slider_btn_txt_partial',
    ) );
}


// blog btn url setting and control
$wp_customize->add_setting( 'house_state_pro_theme_options[slider_excerpt]', array(
	'sanitize_callback' => 'absint',
	'default'			=> $options['slider_excerpt'],
) );

$wp_customize->add_control( 'house_state_pro_theme_options[slider_excerpt]', array(
	'label'           	=> esc_html__( 'Slider Excerpt', 'house-state-pro' ),
	'section'        	=> 'house_state_pro_slider_section',
	'active_callback' 	=> 'house_state_pro_is_slider_section_enable',
	'type'				=> 'number',
) );


//slider Style

$wp_customize->add_setting( 'house_state_pro_theme_options[style_slider_overlay_enable]', array(
	'default'			=> 	$options['style_slider_overlay_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[style_slider_overlay_enable]', array(
	'label'             => esc_html__( 'Slider Overlay Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_slider_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

$wp_customize->add_setting('house_state_pro_theme_options[style_slider_clip_path]',
    array(
        'sanitize_callback' => 'sanitize_text_field',    
    )
);

$wp_customize->add_control('house_state_pro_theme_options[style_slider_clip_path]',
    array(
        'section'			=> 'house_state_pro_slider_section',
        'label'				=> esc_html__( 'Clip Path Code:', 'house-state-pro' ),
        'description'		=> wp_kses_post( 'Generate the clip path code form <a href="https://bennettfeely.com/"> Bennettfeely</a>. Then code the code and paste here.', 'house-state-pro' ),
        'type'          	=>'text',
    )
);

$wp_customize->add_setting( 'house_state_pro_theme_options[style_slider_content_alignment]', array(
	'default'          	=> 'center',
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[style_slider_content_alignment]', array(
	'label'             => esc_html__( 'Content Alignment', 'house-state-pro' ),
	'section'           => 'house_state_pro_slider_section',
	'type'				=> 'select',
	'choices'			=> array( 
            'center'	=> esc_html__( 'Center', 'house-state-pro' ),
            'left' 		=> esc_html__( 'Left', 'house-state-pro' ),
            'right' 	=> esc_html__( 'Right', 'house-state-pro' ),
	),
) );

