<?php
/**
 * Banner section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */
if ( ! function_exists( 'house_state_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since House State Pro 1.0.0
    */
    function house_state_pro_add_counter_section() {
    	$options = house_state_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'house_state_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }
   
        // Render counter section now.
        house_state_pro_render_counter_section( );
}

endif;


if ( ! function_exists( 'house_state_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since House State Pro 1.0.0
   *
   */
   function house_state_pro_render_counter_section( $content_details = array() ) {
        $options = house_state_pro_get_theme_options();
        $counter_background = !empty( $options['counter_background'] ) ? $options['counter_background'] : '';

        ?>
        <div id="house_state_pro_counter_section">
             <div id="counter-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $counter_background ); ?>');">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( !empty( $options['team_section_title'] ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $options['counter_section_title'] ) ; ?></h2>
                    <?php endif ?>
                    <span class="separator">
                        <svg>
                          <g>
                            <path stroke="#A38041" stroke-width="3" d="M0 0 l215 0" />
                            <path stroke="#A38041" stroke-width="2" d="M5,100 v-100" />
                            <path stroke="#A38041" stroke-width="2" d="M10,8 v-50" />
                            <path stroke="#A38041" stroke-width="2" d="M15,8 v-50" />
                            <path stroke="#A38041" stroke-width="2" d="M20 0 v600 400" />
                            <path stroke="#A38041" stroke-width="2" d="M25,8 v-50" />
                            <path stroke="#A38041" stroke-width="2" d="M30,8 v-50" />
                            <path stroke="#A38041" stroke-width="2" d="M35 0 v600 400" />
                            <path stroke="#A38041" stroke-width="2" d="M40,8 v-50" />
                            <path stroke="#A38041" stroke-width="2" d="M45,8 v-50" />
                            <path stroke="#A38041" stroke-width="2" d="M50 0 v600 400" />
                            <path stroke="#A38041" stroke-width="2" d="M55,8 v-50" />
                            <path stroke="#A38041" stroke-width="2" d="M60 0 v600 400" />
                          </g>
                        </svg>
                    </span><!-- .separator -->
                </div><!-- .section-header -->

                <!-- supports column 1, 2 and 4 alaso -->
                <div class="section-content <?php echo esc_attr( $options['counter_column'] ); ?> clear">
                    <?php for ($i=1; $i <= $options['counter_count'] ; $i++) : 
                        $icon = !empty($options['counter_content_icon_'.$i]) ? $options['counter_content_icon_'.$i] : '';
                    ?>
                        <article>
                            <div class="counter-item">
                                <?php if ( !empty( $icon ) ): ?>
                                    <div class="counter-icon">
                                        <i class="fa <?php echo esc_attr( $icon ) ?>"></i>
                                    </div><!-- .counter-icon -->
                                <?php endif ?>
                               <?php if ( array_key_exists( 'counter_section_number_'.$i, $options ) ): ?>
                                    <h2 class="counter-value"><?php echo esc_html( $options['counter_section_number_'.$i] ); ?></h2>
                               <?php endif ?>
                                <?php if ( array_key_exists( 'counter_section_text_'.$i, $options ) ): ?>
                                    <h3 class="counter-title"><?php echo esc_html( $options['counter_section_text_'.$i] ); ?></h3>
                               <?php endif ?>
                               
                            </div><!-- .counter-item -->
                        </article>
                    <?php endfor; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #counters-section -->       
        </div>
       
    <?php
    }    
endif;


