<?php
/**
 * Latest Products section
 *
 * This is the template for the content of latest_products section
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */
if ( ! function_exists( 'house_state_pro_add_latest_products_section' ) ) :
    /**
    * Add latest_products section
    *
    *@since House State Pro 1.0.0
    */
    function house_state_pro_add_latest_products_section() {
    	$options = house_state_pro_get_theme_options();
        // Check if latest_products is enabled on frontpage
        $latest_products_enable = apply_filters( 'house_state_pro_section_status', true, 'latest_products_section_enable' );

        if ( ( true !== $latest_products_enable) ) {
            return false;
        }
  

        // Render latest_products section now.
        house_state_pro_render_latest_products_section( );
    }
endif;



if ( ! function_exists( 'house_state_pro_render_latest_products_section' ) ) :
  /**
   * Start latest_products section
   *
   * @return string latest_products content
   * @since House State Pro 1.0.0
   *
   */
   function house_state_pro_render_latest_products_section( $content_details = array() ) {
        $options = house_state_pro_get_theme_options();
        ?>
        <div id="house_state_pro_latest_products_section">
               <div id="latest-products" class="relative page-section same-background">
            <div class="wrapper">
                <div class="col-2 clear">
                    
                <?php for($i=1; $i <= $options['latest_products_count'] ; $i++): 
                    if ( $options['latest_products_content_type'] == 'category') {
                        $image = z_taxonomy_image_url( $options['latest_products_content_category_' . $i ] );
                        $title = get_cat_name( $options['latest_products_content_category_' . $i ] );
                        $category_link = get_category_link( $options['latest_products_content_category_' . $i ] );
                    }else if ( $options['latest_products_content_type'] == 'product-category'){
                        $thumbnail_id = get_term_meta(  $options['latest_products_content_product_category_'. $i], 'thumbnail_id', true );
                        $image = wp_get_attachment_url( $thumbnail_id );
                        $category_link = get_term_link( $options['latest_products_content_product_category_'. $i], 'product_cat' );
                        $title = get_term_by( 'id', $options['latest_products_content_product_category_' . $i ], 'product_cat' )->name;
                       
                        
                    }

                ?>
                    
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                            <div class="entry-container">
                                <header class="entry-header">
                                   <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url(  $category_link ); ?>"><?php echo esc_html(  $title ); ?></a></h2>
                                    </header>
                                </header>
                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>

                <?php endfor; ?>

                </div><!-- .grid --> 
            </div><!-- .wrapper -->
        </div><!-- #latest-products -->
        </div>
     

    <?php }
endif;