<?php

$options = house_state_pro_get_theme_options();

if ( $options['three_column_posts_section_enable'] == false) {
   return;
}

// Content type.
$three_column_posts_content_type    = $options['three_column_posts_content_type'];
$three_column_posts_count           = ! empty( $options['three_column_posts_count'] ) ? $options['three_column_posts_count'] : 3;

$content = array();
switch ( $three_column_posts_content_type ) {
    
    case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $three_column_posts_count; $i++ ) {
            if ( ! empty( $options['three_column_posts_content_page_' . $i] ) )
                $page_ids[] = $options['three_column_posts_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $three_column_posts_count ),
            'orderby'           => 'post__in',
            );                    
    break;

    case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $three_column_posts_count; $i++ ) {
            if ( ! empty( $options['three_column_posts_content_post_' . $i] ) )
                $post_ids[] = $options['three_column_posts_content_post_' . $i];
        }
        
        $args = array(
            'post_type'             => 'post',
            'post__in'              => ( array ) $post_ids,
            'posts_per_page'        => absint( $three_column_posts_count ),
            'orderby'               => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
    break;

    case 'category':
        $cat_id = ! empty( $options['three_column_posts_category'] ) ? $options['three_column_posts_category'] : '';
        $args = array(
            'post_type'             => 'post',
            'posts_per_page'        => absint( $three_column_posts_count ),
            'cat'                   => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
            );                    
    break;

    default:
    break;
}

// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    $i = 1;
    while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['title']     = get_the_title();
        $page_post['url']       = get_the_permalink();
        $page_post['author']    = house_state_pro_author();
        $page_post['excerpt']   = house_state_pro_trim_content( $options['three_column_posts_excerpt'] );
        $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

        // Push to the main array.
        array_push( $content, $page_post );
    endwhile;
    $i++;
endif;
wp_reset_postdata();


?>
<div id="house_state_pro_three_column_posts_section">
     <div id="magazine-three-column-posts">
        <div class="section-header">
            <?php if ( !empty( $options['three_column_posts_section_title'] ) ): ?>
                <h2 class="section-title"><?php echo esc_html( $options['three_column_posts_section_title'] ) ; ?></h2>
            <?php endif ?>
        </div><!-- .section-header -->

        <div class="col-3 clear">
            <?php foreach ($content as $data ): ?>
                <article>
                    <div class="featured-post-item">
                        <div class="featured-image">
                            <img src="<?php echo esc_url( $data['image'] ) ; ?>">

                            <?php house_state_pro_posted_on( $data['id'] ); ?>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <?php  the_category( '', '', $data['id'] ) ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $data['url'] ) ; ?>"><?php echo esc_html( $data['title'] ) ; ?></a></h2>
                            </header>   

                            <div class="entry-content">
                                <p><?php echo esc_html( $data['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        </div><!-- .entry-container -->
                    </div><!-- .featured-post-item -->
                </article>
            <?php endforeach ?>
            
        </div><!-- .col-3 -->
    </div><!-- #magazine-three-column-posts -->

</div>

